@@ -18,6 +18,8 @@ from multiprocessing import Process, Queue
 import requests
 import botocore
 import shutil
+import pkg_resources
+from tabulate import tabulate
 from cogniceptshell.common import bcolors
 from cogniceptshell.common import generate_progress_bar
 from cogniceptshell.common import permission_safe_docker_call
@@ -681,3 +683,27 @@ class AgentLifeCycle:
                 time.sleep(1.0)
         # If the loop is completed, login failed, so return false
         return False
+
+    def display_version(object,args):
+        """
+        Display Cognicept-Shell version and docker images version
+
+        Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+        """
+        version = pkg_resources.require("cognicept-shell")[0].version
+        data = {}
+        images_version = []
+        data['Container Name'] = object._docker_container_names
+        # default value for version: "unknown/latest"
+        for x in object._docker_images:
+            image_data = object._docker_images[x].split(':')
+            if len(image_data)>1:
+                images_version.append(image_data[1])
+                image_data = []
+            else:
+                images_version.append("unknown/latest")
+        data['Version'] = images_version
+        print("Cognicept Shell Version "+version)
+        print(tabulate(data, headers='keys', tablefmt='psql'))
+        print("Runtime enviroment file directory: " +args.path)
