@@ -25,6 +25,8 @@ parser.add_argument('--version', action='version',
 
 subparsers = parser.add_subparsers(help='', title="Commands")
 
+parser_version = subparsers.add_parser(
+    'version', help='Display Cognicept Version')
 parser_config = subparsers.add_parser(
     'config', help='Configure Cognicept tools')
 parser_status = subparsers.add_parser(
@@ -51,6 +53,8 @@ parser_init = subparsers.add_parser(
 
 DEFAULT_PATH = "~/.cognicept/"
 
+parser_version.add_argument(
+    '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 parser_config.add_argument(
     '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 parser_config.add_argument(
@@ -147,6 +151,7 @@ from cogniceptshell.pusher import Pusher
 parser_config.set_defaults(func=local_cfg.configure)
 parser_keyrotate.set_defaults(func=local_cfg.cognicept_key_rotate)
 agent_lifetime = AgentLifeCycle()
+parser_version.set_defaults(func=agent_lifetime.display_version)
 parser_status.set_defaults(func=agent_lifetime.status)
 parser_lastevent.set_defaults(func=agent_lifetime.get_last_event)
 parser_restart.set_defaults(func=agent_lifetime.restart)
